dds_create_guardcondition

Function dds_create_guardcondition 

pub unsafe extern "C" fn dds_create_guardcondition(
    owner: dds_entity_t,
) -> dds_entity_t
@brief Creates a guardcondition. @ingroup guardcondition @component guard_condition

Waitsets allow waiting for an event on some of any set of entities. This means that the guardcondition can be used to wake up a waitset when data is in the reader history with states that matches the given mask.

@param[in] owner Participant on which to create the guardcondition.

@returns A valid condition handle or an error code.

@retval >0 A valid condition handle @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.