dds_create_reader

Function dds_create_reader 

pub unsafe extern "C" fn dds_create_reader(
    participant_or_subscriber: dds_entity_t,
    topic: dds_entity_t,
    qos: *const dds_qos_t,
    listener: *const dds_listener_t,
) -> dds_entity_t
@brief Creates a new instance of a DDS reader. @ingroup reader @component reader

When a participant is used to create a reader, an implicit subscriber is created. This implicit subscriber will be deleted automatically when the created reader is deleted.

@param[in] participant_or_subscriber The participant or subscriber on which the reader is being created. @param[in] topic The topic to read. @param[in] qos The QoS to set on the new reader (can be NULL). @param[in] listener Any listener functions associated with the new reader (can be NULL).

@returns A valid reader handle or an error code.

@retval >0 A valid reader handle. @retval DDS_RETCODE_ERROR An internal error occurred.

DOC_TODO: Complete list of error codes