dds_create_statistics

Function dds_create_statistics 

pub unsafe extern "C" fn dds_create_statistics(
    entity: dds_entity_t,
) -> *mut dds_statistics
@brief Allocate a new statistics object for entity @ingroup statistics @component statistics @unstable

This allocates and populates a newly allocated struct dds_statistics for the specified entity.

@param[in] entity the handle of the entity

@returns a newly allocated and populated statistics structure or NULL if entity is invalid or doesn’t support any statistics.