dds_create_topic

Function dds_create_topic 

pub unsafe extern "C" fn dds_create_topic(
    participant: dds_entity_t,
    descriptor: *const dds_topic_descriptor_t,
    name: *const c_char,
    qos: *const dds_qos_t,
    listener: *const dds_listener_t,
) -> dds_entity_t
@brief Creates a new topic with default type handling. @ingroup topic @component topic

The type name for the topic is taken from the generated descriptor. Topic matching is done on a combination of topic name and type name. Each successful call to dds_create_topic creates a new topic entity sharing the same QoS settings with all other topics of the same name.

@param[in] participant Participant on which to create the topic. @param[in] descriptor An IDL generated topic descriptor. @param[in] name Name of the topic. @param[in] qos QoS to set on the new topic (can be NULL). @param[in] listener Any listener functions associated with the new topic (can be NULL).

@returns A valid, unique topic handle or an error code.

@retval >=0 A valid unique topic handle. @retval DDS_RETCODE_BAD_PARAMETER Either participant, descriptor, name or qos is invalid. @retval DDS_RETCODE_INCONSISTENT_POLICY QoS mismatch between qos and an existing topic’s QoS. @retval DDS_RETCODE_PRECONDITION_NOT_MET Mismatch between type name in descriptor and pre-existing topic’s type name.