dds_create_writer

Function dds_create_writer 

pub unsafe extern "C" fn dds_create_writer(
    participant_or_publisher: dds_entity_t,
    topic: dds_entity_t,
    qos: *const dds_qos_t,
    listener: *const dds_listener_t,
) -> dds_entity_t
@brief Creates a new instance of a DDS writer. @ingroup writer @component writer

When a participant is used to create a writer, an implicit publisher is created. This implicit publisher will be deleted automatically when the created writer is deleted.

@param[in] participant_or_publisher The participant or publisher on which the writer is being created. @param[in] topic The topic to write. @param[in] qos The QoS to set on the new writer (can be NULL). @param[in] listener Any listener functions associated with the new writer (can be NULL).

@returns A valid writer handle or an error code.

@returns >0 A valid writer handle. @returns DDS_RETCODE_ERROR An internal error occurred.

DOC_TODO: Complete list of error codes