pub unsafe extern "C" fn dds_dynamic_member_set_optional(
type_: *mut dds_dynamic_type_t,
member_id: u32,
is_optional: bool,
) -> dds_return_tExpand description
@brief Set the optional flag for a Dynamic Type member @ingroup dynamic_type @component dynamic_type_api
@param[in,out] type Dynamic Type that contains the member to set the optional flag for (must be a structure type). @param[in] member_id The ID of the member to set the flag for. @param[in] is_optional Indicates whether the optional flag should be set or cleared.
@return dds_return_t Return code. In case of an error, the return code field in the provided type is also set to this value.
@retval DDS_RETCODE_OK The flag is updated successfully. @retval DDS_RETCODE_BAD_PARAMETER One or more of the provided parameters are invalid. @retval DDS_RETCODE_PRECONDITION_NOT_MET The provided type is not in the CONSTRUCTING state.