dds_get_inconsistent_topic_status

Function dds_get_inconsistent_topic_status 

pub unsafe extern "C" fn dds_get_inconsistent_topic_status(
    topic: dds_entity_t,
    status: *mut dds_inconsistent_topic_status_t,
) -> dds_return_t
@ingroup dcps_status_getters @component entity_status @brief Get INCONSISTENT_TOPIC status

This operation gets the status value corresponding to INCONSISTENT_TOPIC and reset the status. The value can be obtained, only if the status is enabled for an entity. NULL value for status is allowed and it will reset the trigger value when status is enabled.

@param[in] topic The topic entity to get the status @param[out] status The pointer to @ref dds_inconsistent_topic_status_t to get the status

@returns 0 - Success @returns <0 - Failure

@retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.