dds_get_instance_handle

Function dds_get_instance_handle 

pub unsafe extern "C" fn dds_get_instance_handle(
    entity: dds_entity_t,
    ihdl: *mut dds_instance_handle_t,
) -> dds_return_t
@brief Returns the instance handle that represents the entity. @ingroup entity @component generic_entity

@param[in] entity Entity of which to get the instance handle. @param[out] ihdl Pointer to dds_instance_handle_t.

@returns A dds_return_t indicating success or failure.

@retval DDS_RETCODE_OK Success. @retval DDS_RETCODE_ERROR An internal error has occurred. DOC_TODO: Check list of return codes is complete.