dds_get_sample_lost_status

Function dds_get_sample_lost_status 

pub unsafe extern "C" fn dds_get_sample_lost_status(
    reader: dds_entity_t,
    status: *mut dds_sample_lost_status_t,
) -> dds_return_t
@ingroup dcps_status_getters @component entity_status @brief Get SAMPLE_LOST status

This operation gets the status value corresponding to SAMPLE_LOST and reset the status. The value can be obtained, only if the status is enabled for an entity. NULL value for status is allowed and it will reset the trigger value when status is enabled.

@param[in] reader The reader entity to get the status @param[out] status The pointer to @ref dds_sample_lost_status_t to get the status

@returns A dds_return_t indicating success or failure

@retval DDS_RETCODE_OK Success @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.