dds_get_topic

Function dds_get_topic 

pub unsafe extern "C" fn dds_get_topic(
    entity: dds_entity_t,
) -> dds_entity_t
@brief Get the topic @ingroup entity @component entity_relations

This operation returns a topic (handle) when the function call is done with reader, writer, read condition or query condition. For instance, it will return the topic when it is used for creating the reader or writer. For the conditions, it returns the topic that is used for creating the reader which was used to create the condition.

@param[in] entity The entity.

@returns A dds_return_t indicating success or failure.

@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER The entity parameter is not a valid parameter. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.