pub unsafe extern "C" fn dds_instance_get_key(
entity: dds_entity_t,
ih: dds_instance_handle_t,
data: *mut c_void,
) -> dds_return_tExpand description
@brief This operation takes an instance handle and return a key-value corresponding to it. @ingroup instance_handle @component data_instance
@param[in] entity Reader, writer, readcondition or querycondition entity. @param[in] ih Instance handle. @param[out] data pointer to an instance, to which the key ID corresponding to the instance handle will be returned, the sample in the instance should be ignored.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER One of the parameters was invalid or the topic does not exist. @retval DDS_RETCODE_ERROR An internal error has occurred.
DOC_TODO: Check return codes for completeness