dds_is_shared_memory_available

Function dds_is_shared_memory_available 

pub unsafe extern "C" fn dds_is_shared_memory_available(
    entity: dds_entity_t,
) -> bool
@ingroup loan @component read_data @brief Check if a shared memory is available to reader/writer.

@note dds_request_loan_of_size can be used if and only if dds_is_shared_memory_available returns true.

@param[in] entity the handle of the entity

@returns true if shared memory is available, false otherwise