dds_loan_sample

Function dds_loan_sample 

pub unsafe extern "C" fn dds_loan_sample(
    writer: dds_entity_t,
    sample: *mut *mut c_void,
) -> dds_return_t
@ingroup deprecated @component read_data @brief Loan a sample from the writer. @deprecated Use @ref dds_request_loan @note This function is to be used with dds_write to publish the loaned sample. @note The function can only be used if dds_is_loan_available is true for the writer.

@param[in] writer the writer to loan the buffer from @param[out] sample the loaned sample

@returns DDS_RETCODE_OK if successful, DDS_RETCODE_ERROR otherwise