dds_log

Function dds_log 

pub unsafe extern "C" fn dds_log(
    cat: u32,
    file: *const c_char,
    line: u32,
    func: *const c_char,
    fmt: *const c_char,
    ...
)
@brief Write a log or trace message to the global log/trace.

Write a log or trace message to one (or both) of the currently active sinks.

Direct use of #dds_log is discouraged. Use #DDS_INFO, #DDS_WARNING, #DDS_ERROR, #DDS_FATAL or #DDS_LOG instead.