pub unsafe extern "C" fn dds_lookup_instance(
entity: dds_entity_t,
data: *const c_void,
) -> dds_instance_handle_tExpand description
@brief This operation takes a sample and returns an instance handle to be used for subsequent operations. @ingroup instance_handle @component data_instance
@param[in] entity Reader or Writer entity. @param[in] data Sample with a key fields set.
@returns instance handle or DDS_HANDLE_NIL if instance could not be found from key.