dds_lset_inconsistent_topic

Function dds_lset_inconsistent_topic 

pub unsafe extern "C" fn dds_lset_inconsistent_topic(
    listener: *mut dds_listener_t,
    callback: dds_on_inconsistent_topic_fn,
)
@ingroup listener_setters @component listener_obj @brief Set the inconsistent_topic callback in the listener structure.

Equivalent to calling @ref dds_lset_inconsistent_topic_arg with arg set to the argument passed in dds_create_listener() and reset_on_invoke to true, and throwing away the result.

@param[in,out] listener listener structure to update @param[in] callback the callback to set or a null pointer