pub unsafe extern "C" fn dds_qget_groupdata(
qos: *const dds_qos_t,
value: *mut *mut c_void,
sz: *mut usize,
) -> boolExpand description
@ingroup qos_getters @component qos_obj @brief Get the groupdata from a qos structure
@param[in] qos - Pointer to a dds_qos_t structure storing the policy @param[in,out] value - Pointer that will store the groupdata. If sz = 0, then a null pointer, else it is a pointer to an allocated buffer of sz+1 bytes where the last byte is always 0 @param[in,out] sz - Pointer that will store the size of groupdata
@returns - false iff any of the arguments is invalid or the qos is not present in the qos object