pub unsafe extern "C" fn dds_qget_reader_data_lifecycle(
qos: *const dds_qos_t,
autopurge_nowriter_samples_delay: *mut dds_duration_t,
autopurge_disposed_samples_delay: *mut dds_duration_t,
) -> boolExpand description
@ingroup qos_getters @component qos_obj @brief Get the reader data-lifecycle qos policy
@param[in] qos - Pointer to a dds_qos_t structure storing the policy @param[in,out] autopurge_nowriter_samples_delay - Pointer that will store the delay for auto-purging samples from instances in a no-writer state (optional) @param[in,out] autopurge_disposed_samples_delay - Pointer that will store the delay for auto-purging of disposed instances (optional)
@returns - false iff any of the arguments is invalid or the qos is not present in the qos object