dds_qget_topicdata

Function dds_qget_topicdata 

pub unsafe extern "C" fn dds_qget_topicdata(
    qos: *const dds_qos_t,
    value: *mut *mut c_void,
    sz: *mut usize,
) -> bool
@ingroup qos_getters @component qos_obj @brief Get the topicdata from a qos structure

@param[in] qos - Pointer to a dds_qos_t structure storing the policy @param[in,out] value - Pointer that will store the topicdata. If sz = 0, then a null pointer, else it is a pointer to an allocated buffer of sz+1 bytes where the last byte is always 0 @param[in,out] sz - Pointer that will store the size of topicdata

@returns - false iff any of the arguments is invalid or the qos is not present in the qos object