dds_read_status

Function dds_read_status 

pub unsafe extern "C" fn dds_read_status(
    entity: dds_entity_t,
    status: *mut u32,
    mask: u32,
) -> dds_return_t
@brief Read the status set for the entity @ingroup entity_status @component entity_status

This operation reads the status(es) set for the entity based on the enabled status and mask set. It does not clear the read status(es).

@param[in] entity Entity on which the status has to be read. @param[out] status Returns the status set on the entity, based on the enabled status. @param[in] mask Filter the status condition to be read, 0 means all statuses

@returns A dds_return_t indicating success or failure.

@retval DDS_RETCODE_OK Success. @retval DDS_RETCODE_BAD_PARAMETER The entity parameter is not a valid parameter, status is a null pointer or mask has bits set outside the status range. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object or mask has status bits set that are undefined for the type of entity. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.