dds_read_wl

Function dds_read_wl 

pub unsafe extern "C" fn dds_read_wl(
    reader_or_condition: dds_entity_t,
    buf: *mut *mut c_void,
    si: *mut dds_sample_info_t,
    maxs: u32,
) -> dds_return_t
@brief Read data from the data reader, read or query condition @ingroup reading @component read_data

@deprecated Alias for dds_read where bufsz = maxs.

@param[in] reader_or_condition Reader, readcondition or querycondition entity. @param[in,out] buf An array of maxs pointers to samples. @param[out] si Pointer to an array of @ref dds_sample_info_t returned for each data value. @param[in] maxs Maximum number of samples to read.

@returns A dds_return_t with the number of samples read or an error code

@retval >=0 Number of samples read. @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.