dds_refresh_statistics

Function dds_refresh_statistics 

pub unsafe extern "C" fn dds_refresh_statistics(
    stat: *mut dds_statistics,
) -> dds_return_t
@brief Update a previously created statistics structure with current values @ingroup statistics @component statistics @unstable

Only the time stamp and the values (and “opaque”) may change. The set of keys and the types of the values do not change.

@param[in,out] stat statistics structure to update the values of

@returns success or an error indication

@retval DDS_RETCODE_OK the data was successfully updated @retval DDS_RETCODE_BAD_PARAMETER stats is a null pointer or the referenced entity no longer exists @retval DDS_RETCODE_PRECONDITION_NOT_MET library was deinitialized