pub unsafe extern "C" fn dds_register_instance(
writer: dds_entity_t,
handle: *mut dds_instance_handle_t,
data: *const c_void,
) -> dds_return_tExpand description
@brief Registers an instance @ingroup writing @component data_instance
This operation registers an instance with a key value to the data writer and returns an instance handle that could be used for successive write & dispose operations. When the handle is not allocated, the function will return an error and the handle will be un-touched.
@param[in] writer The writer to which instance has be associated. @param[out] handle The instance handle. @param[in] data The instance with the key value.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object.