pub unsafe extern "C" fn dds_set_guardcondition(
guardcond: dds_entity_t,
triggered: bool,
) -> dds_return_tExpand description
@brief Sets the trigger status of a guardcondition. @ingroup guardcondition @component guard_condition
@param[in] guardcond Guard condition to set the trigger status of. @param[in] triggered The triggered status to set.
@retval DDS_RETCODE_OK Operation successful @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.