pub unsafe extern "C" fn dds_time() -> dds_time_tExpand description
@brief Get the current time in nanoseconds since the UNIX Epoch.
@returns Current time.
pub unsafe extern "C" fn dds_time() -> dds_time_t@brief Get the current time in nanoseconds since the UNIX Epoch.
@returns Current time.