dds_unregister_instance_ih

Function dds_unregister_instance_ih 

pub unsafe extern "C" fn dds_unregister_instance_ih(
    writer: dds_entity_t,
    handle: dds_instance_handle_t,
) -> dds_return_t
@brief Unregisters an instance by instance handle @ingroup writing @component data_instance

This operation unregisters the instance which is identified by the key fields of the given typed instance handle.

@param[in] writer The writer to which instance is associated. @param[in] handle The instance handle.

@returns A dds_return_t indicating success or failure.

@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object.