pub unsafe extern "C" fn dds_wait_for_acks(
publisher_or_writer: dds_entity_t,
timeout: dds_duration_t,
) -> dds_return_tExpand description
@brief Waits at most for the duration timeout for acks for data in the publisher or writer. @ingroup publication @component publisher
This operation blocks the calling thread until either all data written by the publisher or writer is acknowledged by all matched reliable reader entities, or else the duration specified by the timeout parameter elapses, whichever happens first.
@param[in] publisher_or_writer Publisher or writer whose acknowledgments must be waited for @param[in] timeout How long to wait for acknowledgments before time out
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK All acknowledgments successfully received with the timeout. @retval DDS_RETCODE_BAD_PARAMETER The publisher_or_writer is not a valid publisher or writer. @retval DDS_RETCODE_TIMEOUT Timeout expired before all acknowledgments from reliable reader entities were received. @retval DDS_RETCODE_UNSUPPORTED Operation is not supported.