dds_write

Function dds_write 

pub unsafe extern "C" fn dds_write(
    writer: dds_entity_t,
    data: *const c_void,
) -> dds_return_t
@brief Write the value of a data instance @ingroup writing @component write_data

With this API, the value of the source timestamp is automatically made available to the data reader by the service.

@param[in] writer The writer entity. @param[in] data Value to be written.

@returns dds_return_t indicating success or failure.