dds_write_flush

Function dds_write_flush 

pub unsafe extern "C" fn dds_write_flush(
    entity: dds_entity_t,
) -> dds_return_t
@brief Flush a writers batched writes @ingroup writing @component write_data

When using write batching you can manually batch small writes into larger datapackets for network efficiency. The normal dds_write() no longer guarantee that data is sent on the network automatically.

@param[in] entity The writer entity.

@returns A dds_return_t indicating success or failure. @retval DDS_RETCODE_OK The writer successfully forwarded to the network. @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.