dds_writecdr

Function dds_writecdr 

pub unsafe extern "C" fn dds_writecdr(
    writer: dds_entity_t,
    serdata: *mut ddsi_serdata,
) -> dds_return_t
@brief Write a serialized value of a data instance @ingroup writing @component write_data

This call causes the writer to write the serialized value that is provided in the serdata argument. Timestamp and statusinfo fields are set to the current time and 0 (indicating a regular write), respectively.

@param[in] writer The writer entity. @param[in] serdata Serialized value to be written.

@returns A dds_return_t indicating success or failure. On error, some writers failed to flush buffered messages.

@retval DDS_RETCODE_OK The writer successfully wrote the serialized value. @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted. @retval DDS_RETCODE_TIMEOUT The writer failed to write the serialized value reliably within the specified max_blocking_time.