#[repr(C)]pub struct dds_builtintopic_endpoint {
pub key: dds_guid_t,
pub participant_key: dds_guid_t,
pub participant_instance_handle: dds_instance_handle_t,
pub topic_name: *mut c_char,
pub type_name: *mut c_char,
pub qos: *mut dds_qos_t,
}Expand description
@brief Sample structure of the Builtin topic DcpsPublication and DcpsSubscription. @ingroup builtintopic
Fields
key: dds_guid_t< The GUID that uniquely identifies the endpoint on the network
participant_key: dds_guid_t< The GUID of the participant this endpoint belongs to.
participant_instance_handle: dds_instance_handle_t< The instance handle the participant assigned to this enpoint.
topic_name: *mut c_char< The name of the topic, potentially unicode.
type_name: *mut c_char< The name of the type, potentially unicode.
qos: *mut dds_qos_t< The QoS of the endpoint