dds_dynamic_member_descriptor

Struct dds_dynamic_member_descriptor 

#[repr(C)]
pub struct dds_dynamic_member_descriptor { pub name: *const c_char, pub id: u32, pub type_: dds_dynamic_type_spec_t, pub default_value: *mut c_char, pub index: u32, pub num_labels: u32, pub labels: *mut i32, pub default_label: bool, }
@brief Dynamic Type Member descriptor @ingroup dynamic_type

Structure that holds the properities for adding a member to a dynamic type. Depending on the member type, different fields apply and are required.

Fields

name: *const c_char

< Name of the member, required

id: u32

< Identifier of the member, applicable for struct and union members. DDS_DYNAMIC_MEMBER_ID_AUTO can be used to indicate the next available id (current max + 1) should be used.

type_: dds_dynamic_type_spec_t

< Member type, required for struct and union members.

default_value: *mut c_char

< Default value for the member

index: u32

< Member index, applicable for struct and union members. DDS_DYNAMIC_MEMBER_INDEX_START and DDS_DYNAMIC_MEMBER_INDEX_END can be used to add a member as first or last member in the parent type.

num_labels: u32

< Number of labels, required for union members in case not default_label

labels: *mut i32

< Labels for a union member, 1..n required for union members in case not default_label

default_label: bool

< Is default union member