#[repr(C)]pub struct dds_dynamic_type {
pub x: [*mut c_void; 2],
pub ret: dds_return_t,
}Expand description
@brief Dynamic Type @ingroup dynamic_type
Representation of a dynamically created type. This struct has an opaque pointer to the type in the type system. During construction of the type (setting properties and adding members), the internal type has the state ‘CONSTRUCTION’. Once the type is registered, the state is updated to ‘RESOLVED’ and the type cannot be modified.
The ‘ret’ member of this struct holds the return code of operations performed on this type. In case this value is not DDS_RETCODE_OK, the type cannot be used for further processing (e.g. adding members, registering the type, etc.).
Fields
x: [*mut c_void; 2]ret: dds_return_tTrait Implementations
Sourceimpl Clone for dds_dynamic_type
impl Clone for dds_dynamic_type
Sourcefn clone(&self) -> dds_dynamic_type
fn clone(&self) -> dds_dynamic_type
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for dds_dynamic_type
impl Debug for dds_dynamic_type
Sourceimpl Default for dds_dynamic_type
impl Default for dds_dynamic_type
impl Copy for dds_dynamic_type