#[repr(C)]pub struct dds_psmx_metadata {
pub sample_state: dds_loaned_sample_state_t,
pub data_type: dds_loan_data_type_t,
pub instance_id: dds_psmx_instance_id_t,
pub sample_size: u32,
pub guid: dds_guid_t,
pub timestamp: dds_time_t,
pub statusinfo: u32,
pub cdr_identifier: u16,
pub cdr_options: u16,
}Expand description
@brief Describes the data which is transferred in addition to the application data @ingroup psmx
All fields are filled in by Cyclone DDS during the write prior to handing it to the PSMX plug-in. The plug-in is only required to pass the contents to Cyclone DDS on the receiving side.
Fields
sample_state: dds_loaned_sample_state_t< Representation of this sample/key
data_type: dds_loan_data_type_t< Reserved, must be 0
instance_id: dds_psmx_instance_id_t< PSMX instance id for this sample
sample_size: u32< Size of payload
guid: dds_guid_t< GUID of original writer
timestamp: dds_time_t< Source timestamp of DDS sample
statusinfo: u32< DDSI status info (write/dispose/unregister)
cdr_identifier: u16< CDR encoding (DDSI_RTPS_SAMPLE_NATIVE if not serialized)
cdr_options: u16< CDR options field (0 if not serialized)