#[repr(C)]pub struct dds_sample_info {
pub sample_state: dds_sample_state_t,
pub view_state: dds_view_state_t,
pub instance_state: dds_instance_state_t,
pub valid_data: bool,
pub source_timestamp: dds_time_t,
pub instance_handle: dds_instance_handle_t,
pub publication_handle: dds_instance_handle_t,
pub disposed_generation_count: u32,
pub no_writers_generation_count: u32,
pub sample_rank: u32,
pub generation_rank: u32,
pub absolute_generation_rank: u32,
}Expand description
Contains information about the associated data value
Fields
sample_state: dds_sample_state_tSample state
view_state: dds_view_state_tView state
instance_state: dds_instance_state_tInstance state
valid_data: boolIndicates whether there is a data associated with a sample
- true, indicates the data is valid
- false, indicates the data is invalid, no data to read
source_timestamp: dds_time_ttimestamp of a data instance when it is written
instance_handle: dds_instance_handle_thandle to the data instance
publication_handle: dds_instance_handle_thandle to the publisher
disposed_generation_count: u32count of instance state change from NOT_ALIVE_DISPOSED to ALIVE
no_writers_generation_count: u32count of instance state change from NOT_ALIVE_NO_WRITERS to ALIVE
sample_rank: u32indicates the number of samples of the same instance that follow the current one in the collection
generation_rank: u32difference in generations between the sample and most recent sample of the same instance that appears in the returned collection
absolute_generation_rank: u32difference in generations between the sample and most recent sample of the same instance when read/take was called