#[repr(C)]pub struct dds_topic_descriptor {
pub m_size: u32,
pub m_align: u32,
pub m_flagset: u32,
pub m_nkeys: u32,
pub m_typename: *const c_char,
pub m_keys: *const dds_key_descriptor_t,
pub m_nops: u32,
pub m_ops: *const u32,
pub m_meta: *const c_char,
pub type_information: dds_type_meta_ser,
pub type_mapping: dds_type_meta_ser,
pub restrict_data_representation: u32,
}Expand description
@brief Topic Descriptor @ingroup topic_definition @warning Unstable/Private API Contains all meta information about a type, usually produced by the IDL compiler Since this type is not intended for public consumption it can change without warning.
Fields
m_size: u32< Size of topic type
m_align: u32< Alignment of topic type
m_flagset: u32< Flags
m_nkeys: u32< Number of keys (can be 0)
m_typename: *const c_char< Type name
m_keys: *const dds_key_descriptor_t< Key descriptors (NULL iff m_nkeys 0)
m_nops: u32< Number of ops in m_ops
m_ops: *const u32< Marshalling meta data
m_meta: *const c_char< XML topic description meta data
type_information: dds_type_meta_ser< XCDR2 serialized TypeInformation, only present if flag DDS_TOPIC_XTYPES_METADATA is set
type_mapping: dds_type_meta_ser< XCDR2 serialized TypeMapping: maps type-id to type object and minimal to complete type id, only present if flag DDS_TOPIC_XTYPES_METADATA is set
restrict_data_representation: u32< restrictions on the data representations allowed for the top-level type for this topic, only present if flag DDS_TOPIC_RESTRICT_DATA_REPRESENTATION