dds_attach_t

Type Alias dds_attach_t 

pub type dds_attach_t = isize;
@brief Waitset attachment argument. @ingroup waitset

Every entity that is attached to the waitset can be accompanied by such an attachment argument. When the waitset wait is unblocked because of an entity that triggered, then the returning array will be populated with these attachment arguments that are related to the triggered entity.