dds_entity_t

Type Alias dds_entity_t 

pub type dds_entity_t = i32;
@brief Handle to an entity @ingroup entity

A valid entity handle will always have a positive integer value. Should the value be negative, it is one of the DDS_RETCODE_* error codes.