dds_psmx_t

Type Alias dds_psmx_t 

pub type dds_psmx_t = dds_psmx;
@brief Type representing a PSMX Instance in a DDS Domain Entity @ingroup psmx

Each PSMX Instance is represented in a DDS Domain Entity by a pointer to a struct dds_psmx. The PSMX Plugin is responsible for allocating and constructing it on initialization in a constructor as described in the overview.

Aliased Type

#[repr(C)]
pub struct dds_psmx_t { pub ops: dds_psmx_ops, pub instance_name: *const i8, pub priority: i32, pub locator: *mut ddsi_locator, pub instance_id: u32, pub psmx_topics: *mut c_void, }

Fields

ops: dds_psmx_ops

< operations on the PSMX Instance

instance_name: *const i8

< name of this PSMX Instance

priority: i32

< priority for this interface

locator: *mut ddsi_locator

< PSMX Locator for this PSMX Instance

instance_id: u32

< Numeric PSMX Instance ID for this PSMX Instance

psmx_topics: *mut c_void

< Reserved, must be 0