pub type dds_status_id = c_uint;Expand description
@defgroup entity_status (Entity Status) @ingroup entity All entities have a set of “status conditions” (following the DCPS spec), read peeks, take reads & resets (analogously to read & take operations on reader). The “mask” allows operating only on a subset of the statuses. Enabled status analogously to DCPS spec. @{ / /** @brief These identifiers are used to generate the bitshifted identifiers. By using bitflags instead of these IDs the process of building status masks is simplified to using simple binary OR operations. DOC_TODO fix the refs