pub unsafe extern "C" fn dds_create_reader_guid(
participant_or_subscriber: dds_entity_t,
topic: dds_entity_t,
qos: *const dds_qos_t,
listener: *const dds_listener_t,
guid: *mut dds_guid_t,
) -> dds_entity_tExpand description
@ingroup internal @component reader @unstable @brief Create a reader with the specified GUID
@param[in] participant_or_subscriber The participant or subscriber on which the reader is being created. @param[in] topic The topic to read. @param[in] qos The QoS to set on the new reader (can be NULL). @param[in] listener Any listener functions associated with the new reader (can be NULL). @param[in] guid The GUID for the new reader
@returns A valid reader handle or an error code. @see dds_create_reader for details