pub unsafe extern "C" fn dds_create_subscriber(
participant: dds_entity_t,
qos: *const dds_qos_t,
listener: *const dds_listener_t,
) -> dds_entity_tExpand description
@brief Creates a new instance of a DDS subscriber @ingroup subscriber @component subscriber
@param[in] participant The participant on which the subscriber is being created. @param[in] qos The QoS to set on the new subscriber (can be NULL). @param[in] listener Any listener functions associated with the new subscriber (can be NULL).
@returns A valid subscriber handle or an error code.
@retval >0 A valid subscriber handle. @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_BAD_PARAMETER One of the parameters is invalid.