pub unsafe extern "C" fn dds_create_topic_descriptor(
scope: dds_find_scope_t,
participant: dds_entity_t,
type_info: *const dds_typeinfo_t,
timeout: dds_duration_t,
descriptor: *mut *mut dds_topic_descriptor_t,
) -> dds_return_tExpand description
@ingroup topic @component topic @brief Creates topic descriptor for the provided type_info
@param[in] scope The scope used to find the type: DDS_FIND_SCOPE_LOCAL_DOMAIN or DDS_FIND_SCOPE_GLOBAL. In case DDS_FIND_SCOPE_GLOBAL is used, a type lookup request will be sent to other nodes. @param[in] participant The handle of the participant. @param[in] type_info The type (dds_typeinfo_t) of the topic to find. @param[in] timeout The timeout for waiting for the type to become available @param[out] descriptor - Pointer to a dds_topic_descriptor_t pointer that will be allocated and populated. To free allocated memory for this descriptor, use dds_delete_topic_descriptor.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The topic descriptor has been succesfully created. @retval DDS_RETCODE_BAD_PARAMETER Type_info or descriptor parameter not provided, invalid entity (not a participant) or scope invalid. @retval DDS_RETCODE_PRECONDITION_NOT_MET The participant or the type_id was not found. @retval DDS_RETCODE_TIMEOUT Type was not resolved within the provided timeout @retval DDS_RETCODE_UNSUPPORTED Cyclone DDS built without type discovery (cf. DDS_HAS_TYPE_DISCOVERY)