pub unsafe extern "C" fn dds_get_matched_subscription_data(
writer: dds_entity_t,
ih: dds_instance_handle_t,
) -> *mut dds_builtintopic_endpoint_tExpand description
@brief Get a description of a reader matched with the provided writer @ingroup builtintopic @component writer
This operation looks up the reader instance handle in the set of readers matched with the specified writer, returning a freshly allocated sample of the DCPSSubscription built-in topic if found, and NULL if not. The caller is responsible for freeing the memory allocated, e.g. using dds_builtintopic_free_endpoint.
This operation is similar to performing a read of the given instance handle on a reader of the DCPSSubscription built-in topic, but this operation additionally filters on whether the reader is matched by the provided writer.
@param[in] writer The writer. @param[in] ih The instance handle of a reader.
@returns A newly allocated sample containing the information on the reader, or a NULL pointer for any kind of failure.
@retval != NULL The requested data @retval NULL The writer is not valid or ih is not an instance handle of a matched reader.