pub unsafe extern "C" fn dds_get_status_changes(
entity: dds_entity_t,
status: *mut u32,
) -> dds_return_tExpand description
@brief Get changed status(es) @ingroup entity_status @component entity_status
This operation returns the status changes since they were last read.
@param[in] entity Entity on which the statuses are read. @param[out] status Returns the current set of triggered statuses.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK Success. @retval DDS_RETCODE_BAD_PARAMETER The entity parameter is not a valid parameter. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.