pub unsafe extern "C" fn dds_lget_inconsistent_topic(
listener: *const dds_listener_t,
callback: *mut dds_on_inconsistent_topic_fn,
)Expand description
@ingroup listener_getters @component listener_obj @brief Get the inconsistent_topic callback from the listener structure
Equivalent to calling @ref dds_lget_inconsistent_topic_arg with arg and reset_on_invoke set to a null pointer and throwing away the result.
@param[in] listener The pointer to the listener structure, where the callback will be retrieved from @param[out] callback Callback function; may be a null pointer