pub unsafe extern "C" fn dds_lset_data_available(
listener: *mut dds_listener_t,
callback: dds_on_data_available_fn,
)Expand description
@ingroup listener_setters @component listener_obj @brief Set the data_available callback in the listener structure.
@remark: See also the remark on @ref DDS_DATA_AVAILABLE_STATUS)
Equivalent to calling @ref dds_lset_data_available_arg with arg set to the argument passed in dds_create_listener() and reset_on_invoke to true, and throwing away the result.
@param[in,out] listener listener structure to update @param[in] callback the callback to set or a null pointer