pub unsafe extern "C" fn dds_read_guardcondition(
guardcond: dds_entity_t,
triggered: *mut bool,
) -> dds_return_tExpand description
@brief Reads the trigger status of a guardcondition. @ingroup guardcondition @component guard_condition
@param[in] guardcond Guard condition to read the trigger status of. @param[out] triggered The triggered status read from the guard condition.
@retval DDS_RETCODE_OK Operation successful @retval DDS_RETCODE_ERROR An internal error has occurred. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.