pub unsafe extern "C" fn dds_read_next(
reader: dds_entity_t,
buf: *mut *mut c_void,
si: *mut dds_sample_info_t,
) -> dds_return_tExpand description
@brief Read the first unread sample @ingroup reading @component read_data
Equivalent to dds_read_mask(reader, buf, si, 1, 1, DDS_NOT_READ_SAMPLE_STATE).
@param[in] reader The reader entity. @param[in,out] buf A pointer to a sample. @param[out] si The pointer to @ref dds_sample_info_t returned for a data value.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER The entity parameter is not a valid parameter. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.