dds_reader_wait_for_historical_data

Function dds_reader_wait_for_historical_data 

pub unsafe extern "C" fn dds_reader_wait_for_historical_data(
    reader: dds_entity_t,
    max_wait: dds_duration_t,
) -> dds_return_t
@brief Wait until reader receives all historic data @ingroup reader @component reader

The operation blocks the calling thread until either all “historical” data is received, or else the duration specified by the max_wait parameter elapses, whichever happens first. A return value of 0 indicates that all the “historical” data was received; a return value of TIMEOUT indicates that max_wait elapsed before all the data was received.

@param[in] reader The reader on which to wait for historical data. @param[in] max_wait How long to wait for historical data before time out.

@returns a status, 0 on success, TIMEOUT on timeout or a negative value to indicate error.

DOC_TODO: Complete list of error codes