dds_stream_normalize

Function dds_stream_normalize 

pub unsafe extern "C" fn dds_stream_normalize(
    data: *mut c_void,
    size: u32,
    bswap: bool,
    xcdr_version: u32,
    desc: *const dds_cdrstream_desc,
    just_key: bool,
    actual_size: *mut u32,
) -> bool
@brief Normalized and validates CDR data @component cdr_serializer

@param data data sample @param size size of the data @param bswap byte-swapping required @param xcdr_version XCDR version of the CDR data @param desc type descriptor @param just_key indicates if the data is a serialized key or a complete sample @param actual_size is set to the actual size of the data (*actual_size <= size) on successful return @returns True iff validation and normalization succeeded