pub unsafe extern "C" fn dds_strretcode(
ret: dds_return_t,
) -> *const c_charExpand description
@brief Takes the error value and outputs a string corresponding to it.
@param[in] ret Error value to be converted to a string
@returns String corresponding to the error value