pub unsafe extern "C" fn dds_suspend(
publisher: dds_entity_t,
) -> dds_return_tExpand description
@brief Suspends the publications of the Publisher @ingroup publisher @component publisher
This operation is a hint to the Service so it can optimize its performance by e.g., collecting modifications to DDS writers and then batching them. The Service is not required to use the hint.
Every invocation of this operation must be matched by a corresponding call to @see dds_resume indicating that the set of modifications has completed.
@param[in] publisher The publisher for which all publications will be suspended.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK Publications suspended successfully. @retval DDS_RETCODE_BAD_PARAMETER The pub parameter is not a valid publisher. @retval DDS_RETCODE_UNSUPPORTED Operation is not supported.