pub unsafe extern "C" fn dds_triggered(
entity: dds_entity_t,
) -> dds_return_tExpand description
@brief Checks whether the entity has one of its enabled statuses triggered. @ingroup entity @component entity_status
@param[in] entity Entity for which to check for triggered status.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER The entity parameter is not a valid parameter. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object. @retval DDS_RETCODE_ALREADY_DELETED The entity has already been deleted.