pub unsafe extern "C" fn dds_unregister_instance(
writer: dds_entity_t,
data: *const c_void,
) -> dds_return_tExpand description
@brief Unregisters an instance by instance @ingroup writing @component data_instance
This operation reverses the action of register instance, removes all information regarding the instance and unregisters an instance with a key value from the data writer.
@param[in] writer The writer to which instance is associated. @param[in] data The instance with the key value.
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object.