pub unsafe extern "C" fn dds_unregister_instance_ts(
writer: dds_entity_t,
data: *const c_void,
timestamp: dds_time_t,
) -> dds_return_tExpand description
@brief Unregisters an instance by instance with timestamp @ingroup writing @component data_instance
This operation reverses the action of register instance, removes all information regarding the instance and unregisters an instance with a key value from the data writer. It also provides a value for the timestamp explicitly.
@param[in] writer The writer to which instance is associated. @param[in] data The instance with the key value. @param[in] timestamp The timestamp for the unregistration (>= 0).
@returns A dds_return_t indicating success or failure.
@retval DDS_RETCODE_OK The operation was successful. @retval DDS_RETCODE_BAD_PARAMETER One of the given arguments is not valid. @retval DDS_RETCODE_ILLEGAL_OPERATION The operation is invoked on an inappropriate object.