#[repr(C)]pub struct dds_psmx {
pub ops: dds_psmx_ops_t,
pub instance_name: *const c_char,
pub priority: i32,
pub locator: *mut ddsi_locator,
pub instance_id: dds_psmx_instance_id_t,
pub psmx_topics: *mut c_void,
}Expand description
@brief Type representing a PSMX Instance in a DDS Domain Entity @ingroup psmx
Each PSMX Instance is represented in a DDS Domain Entity by a pointer to a struct dds_psmx.
The PSMX Plugin is responsible for allocating and constructing it on initialization in a constructor
as described in the overview.
Fields
ops: dds_psmx_ops_t< operations on the PSMX Instance
instance_name: *const c_char< name of this PSMX Instance
priority: i32< priority for this interface
locator: *mut ddsi_locator< PSMX Locator for this PSMX Instance
instance_id: dds_psmx_instance_id_t< Numeric PSMX Instance ID for this PSMX Instance
psmx_topics: *mut c_void< Reserved, must be 0