pub type dds_guid_t = dds_builtintopic_guid;Expand description
@brief Structure of a GUID in any builtin topic sample. @ingroup builtintopic @ref dds_builtintopic_guid_t is a bit of a weird name for what everyone just calls a GUID, so let us try and switch to using the more logical one.
Aliased Type
#[repr(C)]pub struct dds_guid_t {
pub v: [u8; 16],
}Fields
v: [u8; 16]< 16-byte unique identifier