pub type dds_sequence_t = dds_sequence;Expand description
@ingroup implementation @brief Datastructure of a Sequence type Container for a sequence of bytes. The general model of this type is also used in IDL output, where the uint8_t * _buffer is replaced by the appropriate subtype of what is contained.
Aliased Type
#[repr(C)]pub struct dds_sequence_t {
pub _maximum: u32,
pub _length: u32,
pub _buffer: *mut u8,
pub _release: bool,
}Fields
_maximum: u32< Allocated space in _buffer
_length: u32< Used space in _buffer
_buffer: *mut u8< Sequence of bytes
_release: bool< Whether a CycloneDDS _free method should free the contained buffer. if you put in your own allocated _buffer set this to false to avoid CycloneDDS calling free() on it.